/*
 * J2ME Compass
 * Copyright (C) 2006 Dana Peters
 * http://www.qcontinuum.org/compass
 * 
 * Changed 2009 by Vedran Vidovic.
 * Removed henson.midp.Float class for performance reasons.
 * Removed code unused by SgTimer.
 */

package org.qcontinuum.compass;

import java.util.Enumeration;
import java.util.Vector;

import javax.microedition.lcdui.Choice;
import javax.microedition.lcdui.ChoiceGroup;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Form;


import sg.SgTimer;



public class TimeZoneForm extends Form implements CommandListener {

  private SgTimer sgTimer;
  private Displayable parentDisplayable;
  private Location mLocation;
  
  private ChoiceGroup mTimeZoneChoiceGroup, mDstEnabledChoiceGroup;
  private Command mCancelCommand, mOkCommand;
  private String[] mDaylightChoices = { "Automatic", "Disabled" };
  private Vector mTimeZones;

  public TimeZoneForm(final SgTimer sgTimer, final Displayable parentDisplayable, final Location location) {
    super("Time Zone");
    
    this.sgTimer = sgTimer;
    this.parentDisplayable = parentDisplayable;
    this.mLocation = location;
    this.append(mTimeZoneChoiceGroup = new ChoiceGroup("Time Zone", Choice.EXCLUSIVE));
    mTimeZoneChoiceGroup.append("Unknown", null);
    mTimeZones = TimeZone.getZones(this, -12 * mLocation.LongMinutes / 180, 90);
    int selectedIndex = -1;
    int index = 1;
    for (Enumeration e = mTimeZones.elements(); e.hasMoreElements();) {
      TimeZone timeZone = (TimeZone) e.nextElement();
      mTimeZoneChoiceGroup.append(timeZone.getName(), null);
      if (mLocation.timeZone != null && timeZone.getName().equals(mLocation.timeZone.getName()))
        selectedIndex = index;
      index++;
    }
    if (selectedIndex > -1)
      mTimeZoneChoiceGroup.setSelectedIndex(selectedIndex, true);
    append(mDstEnabledChoiceGroup = new ChoiceGroup("Daylight Saving", Choice.EXCLUSIVE, mDaylightChoices, null));
    mDstEnabledChoiceGroup.setSelectedIndex(mLocation.dstEnabled ? 0 : 1, true);
    addCommand(mOkCommand = new Command("OK", Command.OK, 0));
    addCommand(mCancelCommand = new Command("Back", Command.CANCEL, 0));
    setCommandListener(this);
  }

  public void commandAction(Command c, Displayable d) {
    if (c == mOkCommand) {
      int selectedIndex = mTimeZoneChoiceGroup.getSelectedIndex();
      if (selectedIndex == 0) {
        SgTimer.showAlert("Please select the time zone for this location.", this);
        return;
      }
      else {
        mLocation.timeZone = (TimeZone) mTimeZones.elementAt(selectedIndex - 1);
        mLocation.dstEnabled = mDstEnabledChoiceGroup.getSelectedIndex() == 0;
        
        mLocation.save();
      }
      // Preferences preferences = Compass.getPreferences();
      // if (mDestination)
      // preferences.setDestination(mLocation);
      // else
      // preferences.setLocation(mLocation);
      // preferences.save();
      // Compass.setRefresh(true);
      // Compass.display("Please enter a name to save this location.", 5, new
      // LocationSaveName(mLocation, mParent));
      sgTimer.showCalendar();
    }
    else if (c == mCancelCommand) {
      Display.getDisplay(sgTimer).setCurrent(parentDisplayable);
    }
  }
  
}
