package sg;

import java.util.Calendar;
import java.util.Date;

import javax.microedition.lcdui.Canvas;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;

import org.qcontinuum.astro.RiseSetTime;
import org.qcontinuum.compass.Location;
import org.qcontinuum.compass.LocationLoad;

public class CalendarCanvas extends Canvas implements CommandListener {
  private static final long MILLIS_IN_HOUR = 60 * 60 * 1000;
  private static final long MILLIS_IN_DAY = 24 * MILLIS_IN_HOUR;
  
  private SgTimer sgTimer;
  private Location locationCurrent = new Location();
  private LocationForm locationForm;

  private Calendar calendarFirstRow;
  
  private Command locationAddCommand = new Command("Add location", Command.OK, 0);
  private Command locationSelectCommand = new Command("Select location", Command.OK, 0);
  private Command locationEditCommand = new Command("Edit location", Command.OK, 0);
  private Command locationDeleteCommand = new Command("Delete location", Command.OK, 0);
  private Command backCommand = new Command("Back", Command.CANCEL, 0);
  
  private int linesPerScreen;
  
  public CalendarCanvas(SgTimer sgTimer) {
    this.sgTimer = sgTimer;
    locationForm = new LocationForm(sgTimer, this, locationCurrent);

    addCommand(locationAddCommand);
    addCommand(locationSelectCommand);
    addCommand(locationEditCommand);
    addCommand(locationDeleteCommand);
    addCommand(backCommand);

    setCommandListener(this);

    calendarFirstRow = Calendar.getInstance();
  }

  protected void paint(Graphics graphics) {
    int screenWidth = this.getWidth();
    int screenHeight = this.getHeight();

    graphics.setColor(255, 255, 255);
    graphics.fillRect(0, 0, screenWidth, screenHeight);

    
    Font f = Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_BOLD, Font.SIZE_MEDIUM);
    graphics.setFont(f);
    

    graphics.setColor(0, 0, 0);


    // timeZone.useDaylightTime() -> na mobitelu true / false, ovisno o tome da li je ukljuceno

    StringBuffer sbHeader = new StringBuffer();
    sbHeader.append(locationCurrent.toString());
    
    graphics.drawString(sbHeader.toString(), 0, 0, Graphics.TOP | Graphics.LEFT);
    
    Calendar calendar = Calendar.getInstance(calendarFirstRow.getTimeZone());
    calendar.setTime(calendarFirstRow.getTime());
    
    int fontHeight = f.getHeight();
    int lineCount = screenHeight / fontHeight;
    linesPerScreen = lineCount - 1;
    for (int i = 1; i < lineCount; i++) {
      int vertPos = i * fontHeight;
      RiseSetTime riseSetTime =
        new RiseSetTime(
            locationCurrent.getGmt(calendar.getTime()),
            locationCurrent.getDstOffset(calendar.getTime()),
            locationCurrent.getEarthPosition());

      StringBuffer sbRow = new StringBuffer();
      sbRow.append(getDateStr(calendar)).append(" ");
      sbRow.append(riseSetTime.getRiseTime().get24HourTimeString()).append(" ");
      sbRow.append(riseSetTime.getSetTime().get24HourTimeString());
      
      graphics.drawString(sbRow.toString(), 0, vertPos, Graphics.TOP | Graphics.LEFT);
   
      calendar = addDay(calendar, 1);
    }
  }
  
    
  private Calendar addDay(Calendar calendar, int days) {
    Date date = calendar.getTime();
    long time = date.getTime();
    time += MILLIS_IN_DAY * days;
    date.setTime(time);
    calendar.setTime(date);
    
    return calendar;
  }

  private String getDateStr(Calendar calendar) {
    int year = calendar.get(Calendar.YEAR);
    int month = calendar.get(Calendar.MONTH) + 1;
    int day = calendar.get(Calendar.DAY_OF_MONTH);
    
    StringBuffer sbDate = new StringBuffer();
    sbDate.append(year).append('-');
    if(month < 10) {
      sbDate.append('0');
    }
    sbDate.append(month).append('-');
    if(day < 10) {
      sbDate.append('0');
    }
    sbDate.append(day);
    
    return sbDate.toString();
  }

  public void commandAction(Command command, Displayable displayable) {
    if(command == locationAddCommand) {
      locationCurrent.Name = "";
      locationForm.init();
      SgTimer.show(locationForm);
    }
    else if(command == locationSelectCommand || command == locationDeleteCommand) {
      LocationLoad locationLoad = new LocationLoad(this);
      SgTimer.show(locationLoad);
    }
    else if(command == locationEditCommand) {
      locationForm.init();
      SgTimer.show(locationForm);
    }
    else if(command == backCommand) {
      sgTimer.showTimer();
    }
  }
  
  protected void keyPressed(int keyCode) {
    int gameAction = SgActionUtil.getSgGameAction(this, keyCode);

    switch(gameAction) {
      case Canvas.KEY_NUM0:
        sgTimer.showTimer();
        break;
      case Canvas.UP:
        calendarFirstRow = addDay(calendarFirstRow, -1);
        break;
      case Canvas.DOWN:
        calendarFirstRow = addDay(calendarFirstRow, 1);
        break;
      case Canvas.LEFT:
        calendarFirstRow = addDay(calendarFirstRow, -linesPerScreen);
        break;
      case Canvas.RIGHT:
        calendarFirstRow = addDay(calendarFirstRow, linesPerScreen);
        break;
    }
    
    repaint();
  }
  
  public void updateLocation(final Location location) {
    this.locationCurrent.updateLocation(location);
  }
  
  public Location getLocationCurrent() {
    return locationCurrent;
  }
}
